-----------------------------------------------------------------------
-- Locale
-----------------------------------------------------------------------
local L = AceLibrary("AceLocale-2.2"):new("Violation: PlayerDamageTaken")

L:RegisterTranslations("enUS", function() return {
	["Damage taken"] = true,
	["DT"] = true,
} end)

L:RegisterTranslations("koKR", function() return {
	["Damage taken"] = "받은 피해량",
} end)

-----------------------------------------------------------------------
-- Locals
-----------------------------------------------------------------------

local playerName = nil

local event = {
	eventType = "Damage",
	recipientID = "player",
}

local data = nil
local position = nil
local dirty = 0

-----------------------------------------------------------------------
-- Module declaration
-----------------------------------------------------------------------

local mod = Violation:NewModule("PlayerDamageTaken", "Parser-3.0")
mod.revision = tonumber(("$Revision: 29313 $"):sub(12, -3)) or 1
mod.version = 3

-----------------------------------------------------------------------
-- Module initialization
-----------------------------------------------------------------------

function mod:OnModuleRegister()
	playerName = UnitName("player")
end

function mod:OnModuleEnable()
	self:RegisterParserEvent(event, "OnParserEvent")
end

function mod:OnReset()
	if type(data) == "table" then
		data = self:del(data)
	end

	data = self:new()
	data[playerName] = 0
end

-----------------------------------------------------------------------
-- Module implementation
-----------------------------------------------------------------------

function mod:GetRevision() return self.revision end
function mod:GetDisplayName() return L["Damage taken"] end
function mod:GetShortDisplayName() return L["DT"] end
function mod:GetBroadcastData()
	local x = dirty
	dirty = 0
	return x
end

function mod:IsDirty()
	return dirty > 0 and true or false
end

function mod:OnRemoteData(sender, input)
	data[sender] = (data[sender] or 0) + input
end

function mod:OnParserEvent(event)
	assert(event.recipientID == "player", "Not supposed to get combat events from people except ourselves.")
	if event.amount then
		data[playerName] = data[playerName] + event.amount
		dirty = dirty + event.amount
	end
end

function mod:GetData(player)
	if player then
		return data[player]
	else
		return data
	end
end

