-----------------------------------------------------------------------
-- Locale
-----------------------------------------------------------------------
local L = AceLibrary("AceLocale-2.2"):new("Violation: PlayerHPS")

L:RegisterTranslations("enUS", function() return {
	["Healing per Second"] = true,
	["HPS"] = true,
} end)

L:RegisterTranslations("koKR", function() return {
	["Healing per Second"] = "초당 치유량",
	["HPS"] = "HPS",
} end)

-----------------------------------------------------------------------
-- Locals
-----------------------------------------------------------------------

local playerName = nil

local event = {
	eventType = "Heal",
	sourceID = "player",
}

local data = nil
local position = nil
local dirty = nil
local lastUpdateTime
local seconds = nil
local healingDone = 0

-----------------------------------------------------------------------
-- Module declaration
-----------------------------------------------------------------------

local mod = Violation:NewModule("PlayerHPS", "Parser-3.0")
mod.revision = tonumber(("$Revision: 29313 $"):sub(12, -3)) or 1
mod.version = 3

-----------------------------------------------------------------------
-- Module initialization
-----------------------------------------------------------------------

function mod:OnModuleRegister()
	playerName = UnitName("player")
end

function mod:OnModuleEnable()
	self:RegisterParserEvent(event, "OnParserEvent")
	self:RegisterEvent("PLAYER_REGEN_ENABLED")
end

function mod:OnReset()
	if type(data) == "table" then
		data = self:del(data)
	end

	data = self:new()
	data[playerName] = 0
	seconds = 0
	oldHPS = 0
end

-----------------------------------------------------------------------
-- Module implementation
-----------------------------------------------------------------------

function mod:GetRevision() return self.revision end
function mod:GetDisplayName() return L["Healing per Second"] end
function mod:GetShortDisplayName() return L["HPS"] end
function mod:GetBroadcastData()
	dirty = nil
	return data[playerName]
end

function mod:IsDirty()
	return dirty
end

function mod:OnRemoteData(sender, input)
	-- remote HPS is placed in the damage table, this is done so we don't need to recalc everybody else's HPS.
	data[sender] = input
end

function mod:PLAYER_REGEN_ENABLED()
	lastUpdateTime = nil
end

function mod:OnParserEvent(event)
	assert(event.sourceID == "player", "Not supposed to get combat events from people except ourselves.")
	if event.amount then
		local newTime = GetTime()
		local timeSinceLastUpdate
		-- on the offhand chance that lastUpdateTime is nil at this point (if somehow we do damage before a regen disabled event fires)
		-- make sure that we have a 
		if not lastUpdateTime then
			timeSinceLastUpdate = 0.1
		else
			timeSinceLastUpdate = newTime - lastUpdateTime
		end
		lastUpdateTime = newTime
		seconds = seconds + timeSinceLastUpdate

		healingDone = healingDone + event.amount

		local newHPS = math.floor(healingDone / seconds)
		dirty = data[playerName] == newHPS and nil or true
		data[playerName] = newHPS
	end
end

function mod:GetData(player)
	if player then
		return data[player]
	else
		return data
	end
end

